@@ -611,7 +611,7 @@ getOption("SweaveHooks")[["fig"]]()
 ## ## exp(mean(log(sigma))): this looks almost identical to mean(sigma)
 print(ggplot(test.3, aes(p/n, exp(meanlogsigma.1), color = Est.Scale)) +
       stat_summary(aes(x=ratio), # <- "rounded p/n": --> median over "neighborhood"
-                   fun.y=median, geom='line') +
+                   fun = median, geom='line') +
       geom_point(aes(shape = factor(n)), alpha = alpha.n) +
       geom_hline(yintercept = 1) +
       g.scale_y_log10_1() +
@@ -626,13 +626,13 @@ print(ggplot(test.3, aes(p/n, exp(meanlogsigma.1), color = Est.Scale)) +
 ###################################################
 getOption("SweaveHooks")[["fig"]]()
 print(ggplot(test.3, aes(p/n, sdlogsigma.1*sqrt(n), color = Est.Scale)) +
-      stat_summary(aes(x=ratio), fun.y=median, geom='line') +
+      stat_summary(aes(x=ratio), fun = median, geom='line') +
       geom_point(aes(shape = factor(n)), alpha = alpha.n) +
       ylab(quote(sd(log(hat(sigma)))*sqrt(n))) +
       facet_wrap(~ Psi) +
       geom_point  (data=test.lm.2, alpha=alpha.n, aes(color = Est.Scale)) +
       stat_summary(data=test.lm.2, aes(x=ratio, color = Est.Scale),
-                   fun.y=median, geom='line') +
+                   fun = median, geom='line') +
       scale_shape_discrete(quote(n)) +
       scale_colour_discrete("Scale Est.",
                             labels= lab(test.3   $Est.Scale,
@@ -647,14 +647,14 @@ print(ggplot(test.4,
              aes(p/n, sdlogsigma.1*sqrt(n), color = Est.Scale)) +
       ylim(with(test.4, range(sdlogsigma.1*sqrt(n)))) +
       ylab(quote(sd(log(hat(sigma)))*sqrt(n))) +
-      stat_summary(aes(x=ratio), fun.y=median, geom='line') +
+      stat_summary(aes(x=ratio), fun = median, geom='line') +
       geom_point(aes(shape = Error), alpha = alpha.error) +
       facet_wrap(~ Psi) +
       ## "FIXME" (?): the next 'test.lm' one  give warnings
       geom_point  (data=test.lm, aes(color = Est.Scale), alpha=alpha.n) +
       ##-> Warning: Removed 108 rows containing missing values    (geom_point).
       stat_summary(data=test.lm, aes(x = ratio, color = Est.Scale),
-                   fun.y=median, geom='line') +
+                   fun = median, geom='line') +
       ##-> Warning: Removed 108 rows containing non-finite values (stat_summary).
       g.scale_shape(labels=lab(test.4$Error)) +
       scale_colour_discrete("Scale Est.",
@@ -669,7 +669,7 @@ getOption("SweaveHooks")[["fig"]]()
 t3est2 <- droplevels(subset(test.3, Estimator %in% c("SMD", "MMqE")))
 print(ggplot(t3est2,
              aes(p/n, q, color = Est.Scale)) + ylab(quote(q)) +
-      stat_summary(aes(x=ratio), fun.y=median, geom='line') +
+      stat_summary(aes(x=ratio), fun = median, geom='line') +
       geom_point(aes(shape = factor(n)), alpha = alpha.n) +
       geom_hline(yintercept = 1) +
       g.scale_y_log10_1() +
@@ -684,7 +684,7 @@ print(ggplot(t3est2,
 getOption("SweaveHooks")[["fig"]]()
 print(ggplot(t3est2,
              aes(p/n, M/q, color = Est.Scale)) +
-      stat_summary(aes(x=ratio), fun.y=median, geom='line') +
+      stat_summary(aes(x=ratio), fun = median, geom='line') +
       geom_point(aes(shape = factor(n)), alpha = alpha.n) +
       g.scale_y_log10_0.05() +
       facet_wrap(~ Psi) +
@@ -701,7 +701,7 @@ t1.bi <- droplevels(subset(test.1, Estimator %in% c("SMD", "MMqE") &
                                    Psi == 'bisquare'))
 print(ggplot(t1.bi,
              aes(p/n, q, color = Est.Scale)) +
-      stat_summary(aes(x=ratio), fun.y=median, geom='line') +
+      stat_summary(aes(x=ratio), fun = median, geom='line') +
       geom_point(aes(shape = factor(n)), alpha = alpha.n) +
       geom_hline(yintercept = 1) +
       g.scale_y_log10_1() +
@@ -718,7 +718,7 @@ print(ggplot(t1.bi,
 getOption("SweaveHooks")[["fig"]]()
 print(ggplot(t1.bi,
              aes(p/n, M/q, color = Est.Scale)) +
-      stat_summary(aes(x=ratio), fun.y=median, geom='line') +
+      stat_summary(aes(x=ratio), fun = median, geom='line') +
       geom_point(aes(shape = factor(n)), alpha = alpha.n) +
       g.scale_y_log10_0.05() +
       facet_wrap(~ Error) +
@@ -735,7 +735,7 @@ getOption("SweaveHooks")[["fig"]]()
 print(ggplot(test.2, aes(p/n, efficiency.1, color = Estimator)) +
       geom_point(aes(shape = factor(n)), alpha = alpha.n) +
       geom_hline(yintercept = 0.95) +
-      stat_summary(aes(x=ratio), fun.y=median, geom='line') +
+      stat_summary(aes(x=ratio), fun = median, geom='line') +
       facet_wrap(~ Psi) +
       ylab(quote('efficiency of' ~~ hat(beta))) +
       g.scale_shape(quote(n)) +
@@ -753,7 +753,7 @@ print(ggplot(t.1xt1,
       ylab(quote('efficiency of '~hat(beta))) +
       geom_point(aes(shape = Error), alpha = alpha.error) +
       geom_hline(yintercept = 0.95) +
-      stat_summary(aes(x=ratio), fun.y=median, geom='line') +
+      stat_summary(aes(x=ratio), fun = median, geom='line') +
       g.scale_shape(values=c(16,17,15,3,7,8,9,1,2,4)[-4],
                     labels=lab(t.1xt1$Error)) +
       facet_wrap(~ Psi) +
@@ -770,9 +770,9 @@ print(ggplot(t.2o., aes(p/n, AdB2.1/(1-p/n), color = Estimator)) +
       geom_point(aes(shape=factor(n)),    alpha = alpha.n) +
       geom_point(aes(y=K2AdB2.1/(1-p/n)), alpha = alpha.n) +
       geom_point(aes(y=AdB2t.1),          alpha = alpha.n) +
-      stat_summary(aes(x=ratio),                     fun.y=median, geom='line') +
-      stat_summary(aes(x=ratio, y=K2AdB2.1/(1-p/n)), fun.y=median, geom='line', linetype=2) +
-      stat_summary(aes(x=ratio, y=AdB2t.1),          fun.y=median, geom='line', linetype=3) +
+      stat_summary(aes(x=ratio),                     fun = median, geom='line') +
+      stat_summary(aes(x=ratio, y=K2AdB2.1/(1-p/n)), fun = median, geom='line', linetype=2) +
+      stat_summary(aes(x=ratio, y=AdB2t.1),          fun = median, geom='line', linetype=3) +
       geom_hline(yintercept = 1/0.95) +
       g.scale_y_log10_1() +
       scale_shape_discrete(quote(n)) +
@@ -791,9 +791,9 @@ print(ggplot(t.2ok,
       geom_point(aes(shape=factor(n)),      alpha = alpha.n) +
       geom_point(aes(y=sdK2AdB2.1/(1-p/n)), alpha = alpha.n) +
       geom_point(aes(y=sdAdB2t.1),          alpha = alpha.n) +
-      stat_summary(aes(x=ratio),                       fun.y=median, geom='line') +
-      stat_summary(aes(x=ratio, y=sdK2AdB2.1/(1-p/n)), fun.y=median, geom='line', linetype= 2) +
-      stat_summary(aes(x=ratio, y=sdAdB2t.1),          fun.y=median, geom='line', linetype= 3) +
+      stat_summary(aes(x=ratio),                       fun = median, geom='line') +
+      stat_summary(aes(x=ratio, y=sdK2AdB2.1/(1-p/n)), fun = median, geom='line', linetype= 2) +
+      stat_summary(aes(x=ratio, y=sdAdB2t.1),          fun = median, geom='line', linetype= 3) +
       g.scale_y_log10_0.05() +
       scale_shape_discrete(quote(n)) +
       scale_colour_discrete(name = "Estimator", labels=lab(t.2ok$Estimator))  +
@@ -811,7 +811,7 @@ print(ggplot(t.2en0,
       g.truncate.lines + g.truncate.areas +
       geom_point(aes(shape = factor(n)), alpha = alpha.n) +
       scale_shape_discrete(quote(n)) +
-      stat_summary(aes(x=ratio), fun.y=median, geom='line') +
+      stat_summary(aes(x=ratio), fun = median, geom='line') +
       geom_hline(yintercept = 0.05) +
       g.scale_y_log10_0.05() +
       scale_colour_discrete(name = "Estimator", labels=lab(t.2en0$method.cov))  +
@@ -828,7 +828,7 @@ print(ggplot(tmp, aes(p/n, f.truncate(emplev_1), color = method.cov)) +
       ylab(quote("empirical level "~ list (H[0] : beta[1] == 0) )) +
       g.truncate.line + g.truncate.area +
       geom_point(aes(shape = factor(n)), alpha = alpha.n) +
-      stat_summary(aes(x=ratio), fun.y=median, geom='line') +
+      stat_summary(aes(x=ratio), fun = median, geom='line') +
       geom_hline(yintercept = 0.05) +
       g.scale_y_log10_0.05() +
       g.scale_shape(quote(n)) +
@@ -853,9 +853,9 @@ print(ggplot(t2.25,
       ylab(quote("empirical power "~ list (H[0] : beta[1] == 0.2) )) +
       geom_point(# aes(shape = Error),
           alpha = alpha.error) +
-      stat_summary(fun.y=median, geom='line') +
+      stat_summary(fun = median, geom='line') +
       geom_point  (data=tL2.25, alpha = alpha.n) +
-      stat_summary(data=tL2.25, fun.y=median, geom='line') +
+      stat_summary(data=tL2.25, fun = median, geom='line') +
       ## g.scale_shape("Error", labels=lab(t2.25$Error)) +
       scale_col_D2.25 +
       facet_wrap(~ Psi)
@@ -870,10 +870,10 @@ print(ggplot(t2.25,
              aes(p/n, power_1_0.4, color = method.cov)) +
       ylab(quote("empirical power "~ list (H[0] : beta[1] == 0.4) )) +
       geom_point(alpha = alpha.error) +
-      stat_summary(fun.y=median, geom='line') +
+      stat_summary(fun = median, geom='line') +
       geom_point  (data=tL2.25, alpha = alpha.n) +
       stat_summary(data=tL2.25,
-                   fun.y=median, geom='line') +
+                   fun = median, geom='line') +
       ## g.scale_shape("Error", labels=lab(t2.25$Error)) +
       scale_col_D2.25 +
       facet_wrap(~ Psi)
@@ -889,9 +889,9 @@ print(ggplot(t2.25,
       ylab(quote("empirical power "~ list (H[0] : beta[1] == 0.6) )) +
       geom_point(# aes(shape = Error),
           alpha = alpha.error) +
-      stat_summary(fun.y=median, geom='line') +
+      stat_summary(fun = median, geom='line') +
       geom_point  (data=tL2.25, alpha = alpha.n) +
-      stat_summary(data=tL2.25, fun.y=median, geom='line') +
+      stat_summary(data=tL2.25, fun = median, geom='line') +
       scale_col_D2.25 +
       facet_wrap(~ Psi)
       )
@@ -905,9 +905,9 @@ print(ggplot(t2.25,
              aes(p/n, power_1_0.8, color = method.cov)) +
       ylab(quote("empirical power "~ list (H[0] : beta[1] == 0.8) )) +
       geom_point(alpha = alpha.error) +
-      stat_summary(fun.y=median, geom='line') +
+      stat_summary(fun = median, geom='line') +
       geom_point  (data=tL2.25, alpha = alpha.n) +
-      stat_summary(data=tL2.25, fun.y=median, geom='line') +
+      stat_summary(data=tL2.25, fun = median, geom='line') +
       g.scale_shape("Error", labels=lab(t2.25$Error)) +
       scale_col_D2.25 +
       facet_wrap(~ Psi)
@@ -922,9 +922,9 @@ print(ggplot(t2.25,
              aes(p/n, power_1_1, color = method.cov)) +
       ylab(quote("empirical power "~ list (H[0] : beta[1] == 1) )) +
       geom_point(alpha = alpha.error) +
-      stat_summary(fun.y=median, geom='line') +
+      stat_summary(fun = median, geom='line') +
       geom_point  (data=tL2.25, alpha = alpha.n) +
-      stat_summary(data=tL2.25, fun.y=median, geom='line') +
+      stat_summary(data=tL2.25, fun = median, geom='line') +
       ## g.scale_shape("Error", labels=lab(t2.25$Error)) +
       scale_col_D2.25 +
       facet_wrap(~ Psi)
@@ -964,7 +964,7 @@ print(ggplot(test.5,
              aes(Point, f.truncate(value), color = method.cov)) +
       geom_point(aes(shape = Error), alpha = alpha.error) +
       g.truncate.line + g.truncate.area +
-      stat_summary(fun.y=median, geom='line') +
+      stat_summary(fun = median, geom='line') +
       geom_hline(yintercept = 0.05) +
       g.scale_y_log10_0.05() +
       g.scale_shape(labels=lab(test.5$Error)) +
