@@ -77,6 +77,7 @@ void R_lmrob_S(double *X, double *y, int *n, int *P,
 	       int *K_s, int *max_k, int *max_it_scale,
 	       double *rel_tol, double *inv_tol, double *scale_tol,
                //     ^^^^^^^^^ = refine.tol in R
+	       double *zero_tol,
 	       int* converged, int *trace_lev, int *mts, int *ss, int *cutoff);
 
 void R_lmrob_M_S(double *X1, double *X2, double *y, double *res,
@@ -84,6 +85,7 @@ void R_lmrob_M_S(double *X1, double *X2, double *y, double *res,
 		 double *scale, double *b1, double *b2,
 		 double *rho_c, int *ipsi, double *bb,
 		 int *K_m_s, int *max_k, double *rel_tol, double *inv_tol, double *scale_tol,
+		 double *zero_tol,
 		 int *converged, int *trace_lev,
 		 int *orthogonalize, int *subsample,
 		 int *descent, int *mts, int *ss);
@@ -91,9 +93,9 @@ void R_lmrob_M_S(double *X1, double *X2, double *y, double *res,
 void R_lmrob_MM(double *X, double *y, int *n, int *P,
 		double *beta_initial, double *scale,
 		double *beta_m, double *resid,
-		int *max_it,
-		double *rho_c, int *ipsi, double *loss, double *rel_tol,
-		int *converged, int *trace_lev, int *mts, int *ss);
+		int *max_it, double *rho_c, int *ipsi,
+		double *loss, double *rel_tol,
+		int *converged, int *trace_lev);
 
 void R_subsample(const double *x, const double *y, int *n, int *m,
 		 double *beta, int *ind_space, int *idc, int *idr,
@@ -162,4 +164,4 @@ void F77_NAME(rllarsbi)(
     double *X, double *Y, int *N, int *NP, int *MDX, int *MDT,
     double *TOL, int *NIT, int *K, int *KODE, double *SIGMA, double *THETA,
     double *RS, double *SC1, double *SC2, double *SC3, double *SC4,
-    double *BET0);
+    const double *BET0);
